summaryrefslogtreecommitdiffstats
path: root/EdkCompatibilityPkg
diff options
context:
space:
mode:
Diffstat (limited to 'EdkCompatibilityPkg')
-rw-r--r--EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c6
-rw-r--r--EdkCompatibilityPkg/Compatibility/BootScriptThunkHelper/BootScriptThunkHelper.c4
2 files changed, 5 insertions, 5 deletions
diff --git a/EdkCompatibilityPkg/Compatibility/BootScriptThunkHelper/BootScriptThunkHelper.c b/EdkCompatibilityPkg/Compatibility/BootScriptThunkHelper/BootScriptThunkHelper.c
index f20555d451..5141df8675 100644
--- a/EdkCompatibilityPkg/Compatibility/BootScriptThunkHelper/BootScriptThunkHelper.c
+++ b/EdkCompatibilityPkg/Compatibility/BootScriptThunkHelper/BootScriptThunkHelper.c
@@ -1,9 +1,9 @@
/** @file
Boot Script Helper SMM driver.
- This driver is responsible to restoer BootScriptThunk from SMRAM to AcpiNvs for security considertion.
+ This driver is responsible to store BootScriptThunk from ReservedMemory to SMRAM for security consideration.
-Copyright (c) 2010, Intel Corporation. All rights reserved.<BR>
+Copyright (c) 2010 - 2012, Intel Corporation. All rights reserved.<BR>
This program and the accompanying materials
are licensed and made available under the terms and conditions
diff --git a/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c b/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
index 4a63977115..84881ea6f5 100644
--- a/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
+++ b/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
@@ -827,7 +827,7 @@ InitializeScriptSaveOnS3SaveState (
Status = gBS->LocateProtocol (&gEfiCallerIdGuid, NULL, &DevicePath);
if (EFI_ERROR (Status)) {
//
// This is the first-time loaded by DXE core. reload itself to NVS mem
//
//
// A workaround: Here we install a dummy handle
@@ -861,7 +861,7 @@ InitializeScriptSaveOnS3SaveState (
PageNumber = EFI_SIZE_TO_PAGES (BufferSize + ImageContext.SectionAlignment);
Status = gBS->AllocatePages (
AllocateMaxAddress,
- EfiACPIMemoryNVS,
+ EfiReservedMemoryType,
PageNumber,
&MemoryAddress
);
@@ -915,7 +915,7 @@ InitializeScriptSaveOnS3SaveState (
return EFI_SUCCESS;
} else {
//
// the entry point is invoked after reloading. following code only run in ACPI NVS
//
//
@@ -827,7 +827,7 @@ InitializeScriptSaveOnS3SaveState (
if (EFI_ERROR (Status)) {
//
- // This is the first-time loaded by DXE core. reload itself to NVS mem
+ // This is the first-time loaded by DXE core. reload itself to RESERVED mem
//
//
@@ -915,7 +915,7 @@ InitializeScriptSaveOnS3SaveState (
} else {
//
- // the entry point is invoked after reloading. following code only run in ACPI NVS
+ // the entry point is invoked after reloading. following code only run in RESERVED mem
//
//